#!/bin/bash

# PKGHOME: www.jasspa.com
# AUTHOR: fdeak <ferenc.deak@gmail.com>
# DEPENDS: ncurses xorg

soft='jasspa'
softversion='060909'
packageversion='44.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkgs=( "$buildir/$soft-mesrc-20$softversion-2.tar.gz"
          "$buildir/$soft-metree-20$softversion-2.tar.gz" )
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
numjobs='-j2'

set -e
cd $buildir
rm -rf $src
mkdir $src
cd $src
tar xzf ${srcpkgs[0]}
tar xzf ${srcpkgs[1]}
cd ..
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .

cd $src
find . -perm 666 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

# Build & install the pkg
cd me$softversion/src
make -f linux26.gmk COPTIMISE'='"$CFLAGS"
install -D -m 755 me $dest/usr/bin/me
mkdir -p $dest/usr/share
cp -R $src/jasspa $dest/usr/share/jasspa
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp $dest/usr/share/jasspa/pixmaps/me_gnome_48.png $dest/usr/share/icons/hicolor/48x48/apps/jasspa.png

# Strip binaries and libraries
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Install docs
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a $src/me$softversion/{COPYING,faq.txt,license.txt,readme.txt} \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/share/applications
cat << "EOF" > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Name=Jasspa
Comment=Microemacs Text Editor
Exec=me
Icon=jasspa
Terminal=false
Type=Application
Categories=Application;Development
StartupNotify=false
Encoding=UTF-8
EOF

# Save the build script
mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir; cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/ )

# Create the /install directory
mkdir -p $dest/install
cat > $dest/install/slack-desc << END
      |-----handy-ruler------------------------------------------------------|
jasspa: jasspa - enhanced microemacs text editor
jasspa: 
jasspa: Jasspa's MicroEmacs is an Emacs editor biased towards UNIX users,
jasspa: working across platforms by providing a consistent interface under
jasspa: UNIX, Microsoft Windows 3.1/'95/'98/NT/2K/XP and DOS operating
jasspa: systems.
jasspa: It features syntax highlighling, folding, multiple undo/redo, macro
jasspa: languge, organizer, mailer, calendar, multiple frames and windows and
jasspa: much more See it's internal help for full list of features.
jasspa: 
jasspa: 
END

# Create the slackware package
cd $dest
/sbin/makepkg -l y -c n $dest.tgz
(cd $buildir; md5sum $package.tgz > $package.md5)

